==> lhcsmapi-1.4.53.tar.gz: lhcsmapi-1.4.53/lhcsmapi/gui/pc/IpqFgcPmSearchBaseModule.py <==
from typing import List, Tuple

from lhcsmapi.Time import Time
from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder


def query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
    """ Method querying FGC PM source and timestamp tuple and taking only those corresponding to the given circuits

    :param start_time: start time for a query
    :param end_time: end time for a query
    :param circuit_name: circuit name
    :return: a list of PM source and timestamp tuples corresponding to circuit names
    """
    metadata = SignalMetadata.get_circuit_signal_database_metadata('IPQ', circuit_name, 'PC', 'PM',
                                                                   timestamp_query=start_time)
    source_timestamp_df = QueryBuilder().with_pm() \
        .with_duration(t_start=start_time, t_end=end_time) \
        .with_query_parameters(system='FGC', className=metadata['className'], source='*') \
        .event_query().df

    source_timestamp_mask_df = source_timestamp_df[source_timestamp_df['source'].str.contains(circuit_name)]
    source_timestamp_mask_df = source_timestamp_mask_df.drop_duplicates('timestamp')

    # Convert PC names to circuit names
    output = []
    for index, row in source_timestamp_mask_df.iterrows():
        pc_name = row['source']
        pc_name_split = pc_name.split('.')
        circuit_name = '%s.%s' % (pc_name_split[-2], pc_name_split[-1][0:2])
        output.append((circuit_name, row['timestamp']))

    return output


class IpqFgcPmSearchBaseModule(FgcPmSearchBaseModule):
    """ A class with methods to search for IPQ FGC PM events to fill-in a search field in the FGC PM search module.

    """

    def convert_fgc_pm_entries_to_options(self, fgc_pm_entries: List[Tuple[str, int]]) -> List[str]:
        """ Method converting a list of source and timestamp tuples into a list of strings to be displayed

        :param fgc_pm_entries: a list of FGC PM source and timestamp tuples
        :return: list of strings with FGC PM source and timestamp
        """
        return ['%s: %s' % (fgc_pm_entry[0], Time.to_string(fgc_pm_entry[1])) for fgc_pm_entry in fgc_pm_entries]

    def find_fgc_pm_entries_with_qps(self, start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        self.lbl_search.value = 'Querying PM for FGC events'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.max = 1
        self.progress_search.description = ''

        output = query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name)

        self.lbl_search.value = 'Query completed'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.value = 1
        self.progress_search.description = ''

        return output

==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/lhcsmapi/gui/pc/IpqFgcPmSearchBaseModule.py <==
from typing import List, Tuple

from lhcsmapi.Time import Time
from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder


def query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
    """ Method querying FGC PM source and timestamp tuple and taking only those corresponding to the given circuits

    :param start_time: start time for a query
    :param end_time: end time for a query
    :param circuit_name: circuit name
    :return: a list of PM source and timestamp tuples corresponding to circuit names
    """
    # It is assumed that all IPQ circuits have the same FGC PC className
    metadata = SignalMetadata.get_circuit_signal_database_metadata('IPQ2', 'RQ5.R5', 'PC', 'PM',
                                                                   timestamp_query=start_time)
    source_timestamp_df = QueryBuilder().with_pm() \
        .with_duration(t_start=start_time, t_end=end_time) \
        .with_query_parameters(system='FGC', className=metadata['className'], source='*') \
        .event_query().df

    source_timestamp_mask_df = source_timestamp_df[source_timestamp_df['source'].str.contains(circuit_name)]
    source_timestamp_mask_df = source_timestamp_mask_df.drop_duplicates('timestamp')

    # Convert PC names to circuit names
    output = []
    for index, row in source_timestamp_mask_df.iterrows():
        pc_name = row['source']
        pc_name_split = pc_name.split('.')
        circuit_name = '%s.%s' % (pc_name_split[-2], pc_name_split[-1][0:2])
        output.append((circuit_name, row['timestamp']))

    return output


class IpqFgcPmSearchBaseModule(FgcPmSearchBaseModule):
    """ A class with methods to search for IPQ FGC PM events to fill-in a search field in the FGC PM search module.

    """

    def convert_fgc_pm_entries_to_options(self, fgc_pm_entries: List[Tuple[str, int]]) -> List[str]:
        """ Method converting a list of source and timestamp tuples into a list of strings to be displayed

        :param fgc_pm_entries: a list of FGC PM source and timestamp tuples
        :return: list of strings with FGC PM source and timestamp
        """
        return ['%s: %s' % (fgc_pm_entry[0], Time.to_string(fgc_pm_entry[1])) for fgc_pm_entry in fgc_pm_entries]

    def find_fgc_pm_entries_with_qps(self, start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        self.lbl_search.value = 'Querying PM for FGC events'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.max = 1
        self.progress_search.description = ''

        output = query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name)

        self.lbl_search.value = 'Query completed'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.value = 1
        self.progress_search.description = ''

        return output
